@@ -42,6 +42,10 @@ class Wd(object):
         else:
             return given_reason
 
+    def add_and_commit(self, reason=None):
+        self(self.add_command)
+        self.commit(reason)
+
     def commit(self, reason=None):
         reason = self._reason(reason)
         self(self.commit_command, reason=reason)
@@ -52,13 +56,17 @@ class Wd(object):
         self(self.add_command)
         self.commit(reason=reason)
 
+    def get_version(self, **kw):
+        __tracebackhide__ = True
+        from setuptools_scm import get_version
+        version = get_version(root=str(self.cwd), **kw)
+        print(version)
+        return version
+
     @property
     def version(self):
         __tracebackhide__ = True
-        from setuptools_scm import get_version
-        version = get_version(root=str(self.cwd))
-        print(version)
-        return version
+        return self.get_version()
 
 
 @pytest.yield_fixture(autouse=True)
